package com.nationrel.modules.pdsc.controller;

import com.nationrel.modules.pdsc.entity.ProjectInfo;
import com.nationrel.modules.pdsc.req.ProjectInfoActivateReq;
import com.nationrel.modules.pdsc.req.ProjectInfoListReq;
import com.nationrel.modules.pdsc.req.ProjectInfoReleaseReq;
import com.nationrel.modules.pdsc.service.IProjectInfoService;
import com.nationrel.modules.pdsc.vo.ProjectInfoListVo;
import com.nationrel.modules.pdsc.vo.ProjectInfoVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.IPageExtField;
import org.jeecg.common.api.PageExtField;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.aspect.annotation.PermissionData;
import org.jeecg.common.constant.CommonConstant;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.config.i18n.MessageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.io.IOException;

/**
 * @Description: 项目信息
 * @Author: nationrel
 * @Date: 2024-03-26
 * @Version: V1.0
 */
@Tag(name = "项目信息")
@RestController
@RequestMapping("/pdsc/projectInfo")
@Slf4j
public class ProjectInfoController extends JeecgController<ProjectInfo, IProjectInfoService> {
    @Autowired
    private IProjectInfoService projectInfoService;

    /**
     * 分页列表查询
     *
     * @param projectInfo
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    //@AutoLog(value = "项目信息-分页列表查询")
    @Operation(summary = "项目信息-分页列表查询")
    @GetMapping(value = "/list")
    @PermissionData(pageComponent = "PDSC/projectInfo/ProjectInfoList")
    public Result<IPageExtField<ProjectInfoListVo>> queryPageList(ProjectInfoListReq req,
                                                                  @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                                  @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize) {
        IPageExtField<ProjectInfo> page = new PageExtField<>(ProjectInfo.class, pageNo, pageSize);
        return Result.OK(projectInfoService.list(req, page));
    }

    /**
     * 添加
     *
     * @param projectInfo
     * @return
     */
    @AutoLog(value = "项目信息-添加")
    @Operation(summary = "项目信息-添加")
    @RequiresPermissions("pdsc:project_info:add")
    @PostMapping(value = "/add")
    public Result<String> add(@RequestBody ProjectInfo projectInfo) {
        projectInfoService.saveProjectInfo(projectInfo);
        return Result.OK(MessageUtils.get("nationrel_add_success"));
    }

    /**
     * 编辑
     *
     * @param projectInfo
     * @return
     */
    @AutoLog(value = "项目信息-编辑")
    @Operation(summary = "项目信息-编辑")
    @RequiresPermissions("pdsc:project_info:edit")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> edit(@RequestBody ProjectInfo projectInfo) {
        projectInfoService.updateById(projectInfo);
        return Result.OK(MessageUtils.get("nationrel_edit_success"));
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "项目信息-通过id删除")
    @Operation(summary = "项目信息-通过id删除")
    @RequiresPermissions("pdsc:project_info:delete")
    @DeleteMapping(value = "/delete")
    public Result<String> delete(@RequestParam(name = "id", required = true) String id) {
        projectInfoService.delete(id);
        return Result.OK(MessageUtils.get("nationrel_delete_success"));
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "项目信息-批量删除")
    @Operation(summary = "项目信息-批量删除")
    @RequiresPermissions("pdsc:project_info:deleteBatch")
    @DeleteMapping(value = "/deleteBatch")
    public Result<String> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        projectInfoService.deleteBatch(ids);
        return Result.OK(MessageUtils.get("nationrel_delete_batch_success"));
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    //@AutoLog(value = "项目信息-通过id查询")
    @Operation(summary = "项目信息-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<ProjectInfoVo> queryById(@RequestParam(name = "id", required = true) String id) {
        return Result.OK(projectInfoService.queryById(id));
    }

    /**
     * 导出excel
     *
     * @param request
     * @param projectInfo
     */
    @RequiresPermissions("pdsc:project_info:exportXls")
    @RequestMapping(value = "/exportXls")
    public void exportXls(HttpServletResponse response, ProjectInfoListReq req) throws Exception {
        projectInfoService.exportXls(response, req);
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequiresPermissions("pdsc:project_info:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ProjectInfo.class);
    }

    @Operation(summary = "项目信息-通过id恢复")
    @RequiresPermissions("pdsc:project_info:recovery")
    @RequestMapping(value = "/recovery", method = RequestMethod.POST)
    public Result<String> recovery(@RequestParam(name = "id", required = true) String id) {
        ProjectInfo projectInfo = projectInfoService.getById(id);
        projectInfo.setDelFlag(CommonConstant.DEL_FLAG_0);
        projectInfo.setDeleteTime(null);
        projectInfoService.updateById(projectInfo);
        return Result.OK(MessageUtils.get("nationrel_recovery_success"));
    }

    @AutoLog(value = "项目信息-发布")
    @Operation(summary = "项目信息-发布")
    @RequiresPermissions("pdsc:project_info:release")
    @PostMapping(value = "/release")
    public Result<String> release(@RequestBody @Valid ProjectInfoReleaseReq req) {
        projectInfoService.release(req);
        return Result.OK(MessageUtils.get("nationrel_release_success"));
    }

    @AutoLog(value = "项目信息-激活")
    @Operation(summary = "项目信息-激活")
    @RequiresPermissions("pdsc:project_info:activate")
    @PostMapping(value = "/activate")
    public Result<String> activate(@RequestBody @Valid ProjectInfoActivateReq req) {
        projectInfoService.activate(req);
        return Result.OK(MessageUtils.get("nationrel_activate_success"));
    }

}
